<?php

/**
 * Plugin Manager
 *
 *
 * Created: 2007-02-12
 * Last update: 2007-02-13
 *
 * @link http://deboutv.free.fr/mantis/
 * @author DEBOUT Vincent  <deboutv@free.fr>
 */

define( 'PLUGINS_PLUGINMANAGER_CHECK_VERSION_DEFAULT', OFF );
define( 'PLUGINS_PLUGINMANAGER_CONFIGURE_THRESHOLD_DEFAULT', ADMINISTRATOR );

/**
 * This function return the plugin list
 *
 * @return array
 */
function pluginmanager_get_plugin_list( $p_check = true ) {
    $t_directory = dirname( dirname( dirname( __FILE__ ) ) );
    $t_dir = opendir( $t_directory );

    $t_access_level = user_get_access_level( auth_get_current_user_id(), helper_get_current_project() );
    
    $t_plugin_list = array();
    while( ( $t_file = readdir( $t_dir ) ) !== false ) {
        if ( is_dir( $t_directory . DIRECTORY_SEPARATOR . $t_file ) && $t_file != '.' && $t_file != '..' ) {
            $t_plugin = array();
            $t_plugin['id'] = $t_file;
            $t_file = $t_directory . DIRECTORY_SEPARATOR . $t_file . DIRECTORY_SEPARATOR . 'info.php';
            $t_function = $t_plugin['id'] . '_get_info';
            if ( file_exists( $t_file ) && !function_exists( $t_function ) ) {
                include( $t_file );
                if ( function_exists( $t_function ) ) {
                    $t_plugin_info = $t_function();
                    $t_plugin['name'] = $t_plugin_info['name'];
                    if ( isset( $t_plugin_info['url'] ) ) {
                        $t_plugin['url'] = $t_plugin_info['url'];
                    }
                    $t_plugin['version'] = $t_plugin_info['version'];
                    if ( $p_check && isset( $t_plugin_info['check'] ) && config_get( 'plugins_pluginmanager_check_version', PLUGINS_PLUGINMANAGER_CHECK_VERSION_DEFAULT ) == ON ) {
                        $t_url = @fopen( $t_plugin_info['check'], 'r' );
                        if ( $t_url ) {
                            $t_version = fscanf( $t_url, '%d.%d.%d\n' );
                            $t_version = implode( '.', $t_version );
                            if ( $t_version != $t_plugin_info['version'] ) {
                                $t_plugin['check'] = '<b>' . $t_version . '</b>';
                            } else {
                                $t_plugin['check'] = $t_version;
                            }
                            fclose( $t_url );
                        } else {
                            $t_plugin['check'] = '-';
                        }
                    } else {
                        $t_plugin['check'] = '-';
                    }
                    $t_threshold = config_get( 'plugins_pluginmanager_' . $t_plugin['id'] . '_threshold', PLUGINS_PLUGINMANAGER_CONFIGURE_THRESHOLD_DEFAULT );
                    if ( $t_access_level >= $t_threshold ) {
                        $t_plugin['has_access_level'] = true;
                    } else {
                        $t_plugin['has_access_level'] = false;
                    }
                    $t_plugin_list[] = $t_plugin;
                }
            } elseif( function_exists( $t_function ) ) {
                $t_plugin_info = $t_function();
                $t_plugin['name'] = $t_plugin_info['name'];
                if ( isset( $t_plugin_info['url'] ) ) {
                    $t_plugin['url'] = $t_plugin_info['url'];
                }
                $t_plugin['version'] = $t_plugin_info['version'];
                if ( $p_check && isset( $t_plugin_info['check'] ) && config_get( 'plugins_pluginmanager_check_version', PLUGINS_PLUGINMANAGER_CHECK_VERSION_DEFAULT ) == ON ) {
                    $t_url = @fopen( $t_plugin_info['check'], 'r' );
                    if ( $t_url ) {
                        $t_version = fscanf( $t_url, '%d.%d.%d\n' );
                        $t_version = implode( '.', $t_version );
                        if ( $t_version != $t_plugin_info['version'] ) {
                            $t_plugin['check'] = '<b>' . $t_version . '</b>';
                        } else {
                            $t_plugin['check'] = $t_version;
                        }
                        fclose( $t_url );
                    } else {
                        $t_plugin['check'] = '-';
                    }
                } else {
                    $t_plugin['check'] = '-';
                }
                $t_threshold = config_get( 'plugins_pluginmanager_' . $t_plugin['id'] . '_threshold', PLUGINS_PLUGINMANAGER_CONFIGURE_THRESHOLD_DEFAULT );
                if ( $t_access_level >= $t_threshold ) {
                    $t_plugin['has_access_level'] = true;
                } else {
                    $t_plugin['has_access_level'] = false;
                }
                $t_plugin_list[] = $t_plugin;
            } elseif ( file_exists( $t_directory . DIRECTORY_SEPARATOR . $t_plugin['id'] . DIRECTORY_SEPARATOR . 'index.php' ) ) {
                $t_plugin['name'] = $t_plugin['id'];
                $t_plugin['version'] = '--';
                $t_plugin['check'] = '--';
                if ( $t_access_level >= ADMINISTRATOR ) {
                    $t_plugin['has_access_level'] = true;
                } else {
                    $t_plugin['has_access_level'] = false;
                }
                $t_plugin_list[] = $t_plugin;
            }
        }
    }

    asort( $t_plugin_list );
    return $t_plugin_list;
}

/**
  * This function returns the plugin info file content
  *
  * @param string $p_plugin The plugin
  * @return array
  */
function pluginmanager_get_plugin_info( $p_plugin ) {
    $t_directory = dirname( dirname( dirname( __FILE__ ) ) );
    if ( is_dir( $t_directory . DIRECTORY_SEPARATOR . $p_plugin ) ) {
        $t_file = $t_directory . DIRECTORY_SEPARATOR . $p_plugin . DIRECTORY_SEPARATOR . 'info.php';
        $t_function = $p_plugin . '_get_info';
        if ( file_exists( $t_file ) && !function_exists( $t_function ) ) {
            include( $t_file );
            if ( function_exists( $t_function ) ) {
                return $t_function();
            } else {
                return false;
            }
        } elseif( function_exists( $t_function ) ) {
            return $t_function();
        }
    }
    return false;
}

?>
